====================
:mod:`notify_rs`
====================

.. autosummary-widths:: 1/3
.. automodule:: notify_rs

.. autovariable:: TIMEOUT_NEVER
	:no-docstring:

.. autovariable:: TIMEOUT_DEFAULT
	:no-docstring:

.. autovariable:: URGENCY_LOW
	:no-docstring:

.. autovariable:: URGENCY_NORMAL
	:no-docstring:

.. autovariable:: URGENCY_CRITICAL
	:no-docstring:

.. TODO:: get annotations from type stubs
